@@ -7,10 +7,6 @@ modStats <- function(mydata,  mod = "mod", obs = "obs", type = "default", ...) {
      ## extract variables of interest
     vars <- c(mod, obs)
 
-    ## these are pre-defined type that need a field "date"
-    dateTypes <- c("year", "hour", "month", "season", "weekday", "weekend", "monthyear",
-                   "gmtbst", "bstgmt")
-
     if (any(type %in%  dateTypes)) vars <- c("date", vars)
 
     ## check the data
